
История изменений
=================

0.7 (2013-08-02)
----------------

* Исправлен тег ``{% yandex_map %}``;
* улучшены тесты;
* Python 2.5 больше не поддерживается. Код может еще работать под 2.5, но
  баги, связаннае с 2.5, исправляться больше не будут.

0.6.1 (2012-04-06)
------------------

* функция ``api.get_external_map_url`` и фильтр ``external_map_url``
  для получения ссылки на Яндекс Карту, размещенную у Яндекса

0.6 (2012-03-20)
----------------

* longtitude везде переименованы в longitude;
* фильтр ``static_map_url`` и тег ``yandex_map`` теперь поддерживают
  Point из GeoDjango (можно их применять к PointField с уже заполненными
  координатами);
* тесты запускаются через tox;
* в yandex_maps.api большие функции разбиты на более маленькие, чтоб их можно
  было использовать отдельно.

Для обновления с версии 0.5 выполните миграции south::

     python ./manage.py migrate yandex_maps

и переименуйте все 'longtitude' в 'longitude', если эти атрибуты или
аргументы где-то использовались в коде.

0.5.1 (2010-08-29)
------------------

django-yandex-maps переименован в yandex-maps
